@@ -32,7 +32,7 @@
 
 #include "interfaces/bodypartformatter.h"
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace {
 
