@@ -34,7 +34,7 @@
 
 #include <tqcombobox.h>
 #include <tqvaluelist.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class TQString;
 
