@@ -22,7 +22,7 @@
 #define RESOURCEXMLRPCCONFIG_H
 
 #include <tderesources/configwidget.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class KLineEdit;
 class KURLRequester;
