@@ -23,7 +23,7 @@
 #define RESOURCEFEATUREPLANCONFIG_H
 
 #include <tderesources/configwidget.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class KLineEdit;
 class KURLRequester;
